pub struct PigSoundVariant {
pub key: Identifier,
pub adult_sounds: PigAge,
pub baby_sounds: PigAge,
}Expand description
Represents a set of sounds for a pig variant from a data pack JSON file.
Fields
key: Identifieradult_sounds: PigAgebaby_sounds: PigAgeTrait Implementations
Sourceimpl Debug for PigSoundVariant
impl Debug for PigSoundVariant
impl Eq for PigSoundVariant
Sourceimpl PartialEq for PigSoundVariant
impl PartialEq for PigSoundVariant
Sourceimpl RegistryEntry for PigSoundVariant
impl RegistryEntry for PigSoundVariant
Sourceimpl RegistryReferenceEntry for PigSoundVariant
impl RegistryReferenceEntry for PigSoundVariant
Sourceconst REGISTRY_NAME: &'static str = "pig sound variant"
const REGISTRY_NAME: &'static str = "pig sound variant"
Human-readable registry name used in codec errors.
Sourcefn reference_by_id(id: usize) -> Option<&'static Self>
fn reference_by_id(id: usize) -> Option<&'static Self>
Looks up an entry by its protocol registry ID.
Sourcefn reference_by_key(key: &Identifier) -> Option<&'static Self>
fn reference_by_key(key: &Identifier) -> Option<&'static Self>
Looks up an entry by its registry key.
Sourceimpl ToNbtTag for &PigSoundVariant
impl ToNbtTag for &PigSoundVariant
fn to_nbt_tag(self) -> NbtTag
fn to_optional_nbt_tag(self) -> Option<NbtTag>